@@ -18,6 +18,7 @@ from .engine.schemas import *
 
 
 _PROJECTION_RX = re.compile(r"^-?([a-zA-Z][a-zA-Z0-9_-]+)(,[a-zA-Z][a-zA-Z0-9_-]+)*$")
+LOGGER =
 
 
 class ImproperlyConfiguredError(Exception):
@@ -378,7 +379,7 @@ class StorageApp(Flask):
                     return method_not_allowed()
 
                 # Process a "simple" resource.
-                self._logger.debug(f"GET /{resource} (type=single), using filter={filter}")
+                self._logger.debug(f"GET /{resource} (type=simple), using filter={filter}")
                 projection = _parse_projection(request.args.get('projection') or resource_definition.get("projection"))
                 element = collection.find_one(filter=filter, projection=projection)
                 if element:
@@ -454,7 +455,8 @@ class StorageApp(Flask):
                 else:
                     if method_entry["type"] != "operation":
                         return method_not_allowed()
-            except KeyError:
+            except KeyError as e:
+                self._logger.debug(f"Resource methods misconfiguration. Missing key: {e.args}")
                 return not_found()
 
             # Getting the appropriate instance.
@@ -737,7 +739,8 @@ class StorageApp(Flask):
                 else:
                     if method_entry["type"] != "operation":
                         return method_not_allowed()
-            except KeyError:
+            except KeyError as e:
+                self._logger.debug(f"Item methods misconfiguration. Missing key: {e.args}")
                 return not_found()
 
             # Getting the appropriate instance.
